package com.ruoyi.common.pay.tm;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.pay.wx.Payable;
import com.ruoyi.common.pay.wx.RefundAble;
import com.ruoyi.common.utils.http.HttpUtils;
import org.springframework.stereotype.Service;
import java.util.HashMap;

/**
 * 太米支付
 */
@Service
public class TmPayService {

    /**
     * 订单查询
     */
    public static void orderQuery(IChannelInfo channel, String outTradeNo) {
        HashMap<String, String> body = new HashMap<String, String>();
        body.put("tradeId", outTradeNo);
        body.put("terminalType", "1");
        body.put("shopId", channel.getShopId());
        doPost("/open/Pay/orderQuery", body,channel);
    }

    /**
     * 退款
     */
    public static void refund(IChannelInfo channel,RefundAble refundAble) {
        HashMap<String, String> body = new HashMap<String, String>();
        body.put("refundFee", String.valueOf(refundAble.getAmount()));
        body.put("terminalType", "1");
        body.put("tradeId", refundAble.getOutRefundNo());
        body.put("shopId", channel.getShopId());
        doPost("/open/Pay/refund", body,channel);
    }

    /**
     * 关闭订单
     */
    public static void closeOrder(IChannelInfo channel, String outTradeNo) {
        HashMap<String, String> body = new HashMap<String, String>();
        body.put("tradeId", outTradeNo);
        body.put("terminalType", "1");
        body.put("shopId", channel.getShopId());
        doPost("/open/Pay/orderQuery", body,channel);
    }

    /**
     * JSAPI支付
     */
    public void pay(IChannelInfo channel, Payable payable) {
        HashMap<String, String> body = new HashMap<>();
        body.put("payAmount", String.valueOf(payable.getAmount()));
        body.put("terminalType", "1");
        body.put("shopId", channel.getShopId());  // 从渠道获取shopId
        body.put("sn", channel.getSn());
        body.put("payType", "wx_pay");
        body.put("outTradeId", payable.getOutTradeNo());
        body.put("body", payable.getDescription());
        body.put("notifyUrl", channel.getNotifyUrl());
        body.put("frontUrl",  channel.getFrontUrl());

        doPost(channel.getHttpUrl() + "/open/Pay/unifiedOrder", body, channel);
    }

    private static void doPost(String url, HashMap<String, String> body, IChannelInfo channel) {
        body.put("developerId", channel.getDeveloperId());
        body.put("version", "1.0");
        body.put("timestamp", String.valueOf(System.currentTimeMillis() / 1000));
        body.put("nonceStr", StringUtils.getRandomString(16));

        String bodyStr = StringUtils.getAsciiSort(body);
        String sign = Md5Utils.getMD5Code(bodyStr + "&key=" + channel.getSignKey()).toUpperCase();
        body.put("sign", sign);

        HashMap<String, String> headerData = new HashMap<>();
        headerData.put("Content-Type", "application/json");

        String response = HttpUtils.sendPostWithHeaders(url, headerData, JSON.toJSONString(body));
        System.out.println("API Response: " + response);
    }
}
